Change Log
----------

0.1.0-alpha
~~~~~~~~~~~

Released on June 3, 2014

This is the feature relese.

* expanded generate_pdf function with locale param,
* travis-ci support,


0.0.2-alpha
~~~~~~~~~~~

Released on May 14, 2014

This is the bugfix release.

* bugfix installation error,


0.0.1-alpha
~~~~~~~~~~~

Released on March 14, 2014

This is the alpha release of Inkpy.

* alpha release
